summaryrefslogtreecommitdiffstats
path: root/krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h
diff options
context:
space:
mode:
Diffstat (limited to 'krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h')
-rw-r--r--krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h b/krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h
index d833eda..8311925 100644
--- a/krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h
+++ b/krecipes/src/backends/SQLite/libqsqlite/krecqsqliteresult.h
@@ -18,39 +18,39 @@
* (at your option) any later version. *
***************************************************************************/
-#ifndef QSQLITERESULT_H
-#define QSQLITERESULT_H
+#ifndef TQSQLITERESULT_H
+#define TQSQLITERESULT_H
-#include <qdatetime.h>
-#include <qmap.h>
-#include <qvaluelist.h>
+#include <ntqdatetime.h>
+#include <ntqmap.h>
+#include <ntqvaluelist.h>
/**
* ResultRow represents one row of the resulting answer
*/
-class QSQLiteResultRow
+class TQSQLiteResultRow
{
public:
/**
* TableString is used to establish the relations
* between the column name and the real item
*/
- typedef QMap<QString, QCString> TableString;
+ typedef TQMap<TQString, TQCString> TableString;
/**
* TableInt is used to establish a relation between a
* position of a column and the row value
*/
- typedef QMap<int, QCString> TableInt;
+ typedef TQMap<int, TQCString> TableInt;
/**
* Default c'tor. It has a TableString and a TableInt
*/
- QSQLiteResultRow( const TableString& = TableString(),
+ TQSQLiteResultRow( const TableString& = TableString(),
const TableInt& = TableInt() );
- QSQLiteResultRow( const QSQLiteResultRow& );
- ~QSQLiteResultRow();
- QSQLiteResultRow &operator=( const QSQLiteResultRow& );
+ TQSQLiteResultRow( const TQSQLiteResultRow& );
+ ~TQSQLiteResultRow();
+ TQSQLiteResultRow &operator=( const TQSQLiteResultRow& );
/**
* returns the TableString
@@ -66,25 +66,25 @@ public:
* retrieves the Data from columnName
*
*/
- QCString data( const QString& columnName, bool *ok = 0 );
+ TQCString data( const TQString& columnName, bool *ok = 0 );
/**
* QString for column number
*/
- QCString data( int columnNumber, bool *ok = 0 );
+ TQCString data( int columnNumber, bool *ok = 0 );
/**
* Date conversion from columnName
*/
- QDate dataToDate( const QString& columnName, bool *ok = 0 );
+ TQDate dataToDate( const TQString& columnName, bool *ok = 0 );
/**
* Date conversion from column-number
*/
- QDate dataToDate( int columnNumber, bool *ok = 0 );
+ TQDate dataToDate( int columnNumber, bool *ok = 0 );
- QDateTime dataToDateTime( const QString& columName );
- QDateTime dataToDateTime( int columnNumber );
+ TQDateTime dataToDateTime( const TQString& columName );
+ TQDateTime dataToDateTime( int columnNumber );
private:
TableString m_string;
@@ -92,14 +92,14 @@ private:
};
/**
- * the QSQLiteResult
+ * the TQSQLiteResult
* either a SQL statusment failed or succeeded
*/
-class QSQLiteResult
+class TQSQLiteResult
{
public:
- typedef QValueList<QSQLiteResultRow> Columns;
+ typedef TQValueList<TQSQLiteResultRow> Columns;
/** The Status of a Result */
enum Status{ Success = 0, Failure, Undefined };
@@ -110,23 +110,23 @@ public:
* @param r ResultItems
* @param error Error Message
*/
- QSQLiteResult( enum Status status = Undefined,
+ TQSQLiteResult( enum Status status = Undefined,
const Columns &r = Columns(),
- const QString &error = 0L );
- ~QSQLiteResult();
+ const TQString &error = 0L );
+ ~TQSQLiteResult();
Status getStatus() const;
Columns getResults() const;
- QString getError() const;
+ TQString getError() const;
void setStatus( enum Status status );
void setResults( const Columns &result );
- void setError( const QString &error );
+ void setError( const TQString &error );
- void addRow( QSQLiteResultRow row );
+ void addRow( TQSQLiteResultRow row );
- QSQLiteResultRow first();
- QSQLiteResultRow next();
+ TQSQLiteResultRow first();
+ TQSQLiteResultRow next();
bool atEnd();
Columns::ConstIterator iterator() const;
@@ -135,7 +135,7 @@ public:
private:
enum Status m_status;
Columns m_list;
- QString m_error;
+ TQString m_error;
Columns::Iterator it;
};
@@ -66,25 +66,25 @@ public:
/**
- * QString for column number
+ * TQString for column number
*/